Changelog
==========

This document records all notable changes to `seir <github.com/covid19-bh-biostats/seir/>`_.
This project adheres to `Semantic Versioning <https://semver.org/>`_.


0.2.0 (2020-04-08)
------------------

**Added**

* Visualizations of restrictive measures
* Improved documentation
* visualize_compartments is now a flag
* short alternatives for parameters
* Added support for json file output

**Fixed**

**Dependencies**

**Deprecated**

0.1.1 (2020-04-07)
------------------

**Added**

**Fixed**
* pep8 compatibility
* bug when specifying compartment-specific initial populations not as probabilities

**Dependencies**

**Deprecated**

0.1.0 (2020-04-07)
------------------

**Added**
* Created the project using COOKIETEMPLE

**Fixed**

**Dependencies**

**Deprecated**
